### Extension

We provide generic parsers for the following corpus formats:
* CHAT
* Toolbox
* IMDI/CMDI

To create a parser for a new corpus, please follow the instructions at
* `src/acqdiv/parsers/chat/README.md` (CHAT corpus)
* `src/acqdiv/parsers/toolbox/README.md` (Toolbox corpus)
